The set of reference models in ParlAI ("model zoo").

Each directory contains a stored reference model (or set of related models). Typically this is the stored model from training one of the ParlAI agents on one or more of the ParlAI tasks.

The list of models can also be found in the documentation:
http://www.parl.ai/docs/zoo.html

or in this file:
https://github.com/facebookresearch/ParlAI/blob/main/parlai/zoo/model_list.py
